==> jc-1.4.0.tar.gz: java/lang/VMThrowable.c <==
// final class java.lang.VMThrowable

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a817ca1826b12888 java_lang_StackTraceElement
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_StackTraceElement
// @dep_header java_lang_String
// @dep_header java_lang_Throwable
// @dep_header java_lang_VMThrowable

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/StackTraceElement.h"
#include "java/lang/String.h"
#include "java/lang/Throwable.h"
#include "java/lang/VMThrowable.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private byte[] vmdata
static _jc_field _jc_java_lang_VMThrowable$field_info$vmdata = {
	.name=		"vmdata",
	.signature=	"[B",
	.class=		&_jc_java_lang_VMThrowable$type,
	.type=		&_jc_byte$array$prim$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_lang_VMThrowable$object, refs[-1].java_lang_VMThrowable.vmdata),
};

// Fields
static _jc_field *const _jc_java_lang_VMThrowable$fields[] = {
	&_jc_java_lang_VMThrowable$field_info$vmdata
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// static final native java.lang.VMThrowable fillInStackTrace(java.lang.Throwable)
//

static const unsigned char _jc_java_lang_VMThrowable$param_ptypes$fillInStackTrace$78894ac70fa4c0a5[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMThrowable$param_types$fillInStackTrace$78894ac70fa4c0a5[] = {
	&_jc_java_lang_Throwable$type
};

_jc_method _jc_java_lang_VMThrowable$method_info$fillInStackTrace$78894ac70fa4c0a5 = {
	.name=			"fillInStackTrace",
	.signature=		"(Ljava/lang/Throwable;)Ljava/lang/VMThrowable;",
	.class=			&_jc_java_lang_VMThrowable$type,
	.param_types=		&_jc_java_lang_VMThrowable$param_types$fillInStackTrace$78894ac70fa4c0a5,
	.return_type=		&_jc_java_lang_VMThrowable$type,
	.param_ptypes=		&_jc_java_lang_VMThrowable$param_ptypes$fillInStackTrace$78894ac70fa4c0a5,
	.signature_hash=	_JC_JLONG(0x78894ac70fa4c0a5),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMThrowable$method$fillInStackTrace$78894ac70fa4c0a5,
	.num_parameters=	1,
};

_jc_java_lang_VMThrowable$object *
_jc_java_lang_VMThrowable$method$fillInStackTrace$78894ac70fa4c0a5(_jc_env *const env, _jc_java_lang_Throwable$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMThrowable$method_info$fillInStackTrace$78894ac70fa4c0a5, &retval, param0);
	return retval.l;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>()
//

static _jc_linenum _jc_java_lang_VMThrowable$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_lang_VMThrowable$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMThrowable$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMThrowable$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMThrowable$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_java_lang_VMThrowable$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMThrowable$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMThrowable, _init$52f4ad9f2989aeee);

void
_jc_java_lang_VMThrowable$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_lang_VMThrowable$object *this)
{
	struct _jc_java_lang_VMThrowable$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(60);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// final native java.lang.StackTraceElement[] getStackTrace(java.lang.Throwable)
//

static const unsigned char _jc_java_lang_VMThrowable$param_ptypes$getStackTrace$6bf04a7562bb9b69[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMThrowable$param_types$getStackTrace$6bf04a7562bb9b69[] = {
	&_jc_java_lang_Throwable$type
};

_jc_method _jc_java_lang_VMThrowable$method_info$getStackTrace$6bf04a7562bb9b69 = {
	.name=			"getStackTrace",
	.signature=		"(Ljava/lang/Throwable;)[Ljava/lang/StackTraceElement;",
	.class=			&_jc_java_lang_VMThrowable$type,
	.param_types=		&_jc_java_lang_VMThrowable$param_types$getStackTrace$6bf04a7562bb9b69,
	.return_type=		&_jc_java_lang_StackTraceElement$array$type,
	.param_ptypes=		&_jc_java_lang_VMThrowable$param_ptypes$getStackTrace$6bf04a7562bb9b69,
	.signature_hash=	_JC_JLONG(0x6bf04a7562bb9b69),
	.access_flags=		_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMThrowable$method$getStackTrace$6bf04a7562bb9b69,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_VMThrowable$vtable, java_lang_VMThrowable.getStackTrace$6bf04a7562bb9b69) / sizeof(void *),
	.num_parameters=	1,
};

_jc_object_array *
_jc_java_lang_VMThrowable$method$getStackTrace$6bf04a7562bb9b69(_jc_env *const env, _jc_java_lang_VMThrowable$object *this, _jc_java_lang_Throwable$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMThrowable$method_info$getStackTrace$6bf04a7562bb9b69, &retval, this, param0);
	return retval.l;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_VMThrowable$methods[] = {
	&_jc_java_lang_VMThrowable$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_lang_VMThrowable$method_info$fillInStackTrace$78894ac70fa4c0a5,
	&_jc_java_lang_VMThrowable$method_info$getStackTrace$6bf04a7562bb9b69
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_VMThrowable$instanceof_hash_bucket_65[] = {
	&_jc_java_lang_VMThrowable$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_VMThrowable$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_VMThrowable$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[65]=	_jc_java_lang_VMThrowable$instanceof_hash_bucket_65,
	[113]=	_jc_java_lang_VMThrowable$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_VMThrowable$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/StackTraceElement",	_JC_JLONG(0xa817ca1826b12888) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_VMThrowable$vtype _jc_java_lang_VMThrowable$type = {
    .type= {
	.name=			"java/lang/VMThrowable",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xc8d6a6ffc5c1acc1),
		.source_file=		"VMThrowable.java",
		.instance_size=		sizeof(_jc_java_lang_VMThrowable$refs) + sizeof(_jc_java_lang_VMThrowable$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_lang_VMThrowable$fields) / sizeof(*_jc_java_lang_VMThrowable$fields),
		.fields=		_jc_java_lang_VMThrowable$fields,
		.num_methods=		sizeof(_jc_java_lang_VMThrowable$methods) / sizeof(*_jc_java_lang_VMThrowable$methods),
		.methods=		_jc_java_lang_VMThrowable$methods,
		.instanceof_hash_table=	_jc_java_lang_VMThrowable$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_lang_VMThrowable$class_depends) / sizeof(*_jc_java_lang_VMThrowable$class_depends),
		.class_depends=		_jc_java_lang_VMThrowable$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_VMThrowable= {
	    .getStackTrace$6bf04a7562bb9b69=
		&_jc_java_lang_VMThrowable$method$getStackTrace$6bf04a7562bb9b69,
	},
    }
};

==> jc-1.4.5.tar.gz: java/lang/VMThrowable.c <==
// final class java.lang.VMThrowable

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a817ca1826b12888 java_lang_StackTraceElement
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_StackTraceElement
// @dep_header java_lang_String
// @dep_header java_lang_Throwable
// @dep_header java_lang_VMThrowable

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/StackTraceElement.h"
#include "java/lang/String.h"
#include "java/lang/Throwable.h"
#include "java/lang/VMThrowable.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private byte[] vmdata
static _jc_field _jc_java_lang_VMThrowable$field_info$vmdata = {
	.name=		"vmdata",
	.signature=	"[B",
	.class=		&_jc_java_lang_VMThrowable$type,
	.type=		&_jc_byte$array$prim$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_lang_VMThrowable$object, refs[-1].java_lang_VMThrowable.vmdata),
};

// Fields
static _jc_field *const _jc_java_lang_VMThrowable$fields[] = {
	&_jc_java_lang_VMThrowable$field_info$vmdata
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// static final native java.lang.VMThrowable fillInStackTrace(java.lang.Throwable)
//

static const unsigned char _jc_java_lang_VMThrowable$param_ptypes$fillInStackTrace$78894ac70fa4c0a5[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMThrowable$param_types$fillInStackTrace$78894ac70fa4c0a5[] = {
	&_jc_java_lang_Throwable$type
};

_jc_method _jc_java_lang_VMThrowable$method_info$fillInStackTrace$78894ac70fa4c0a5 = {
	.name=			"fillInStackTrace",
	.signature=		"(Ljava/lang/Throwable;)Ljava/lang/VMThrowable;",
	.class=			&_jc_java_lang_VMThrowable$type,
	.param_types=		&_jc_java_lang_VMThrowable$param_types$fillInStackTrace$78894ac70fa4c0a5,
	.return_type=		&_jc_java_lang_VMThrowable$type,
	.param_ptypes=		&_jc_java_lang_VMThrowable$param_ptypes$fillInStackTrace$78894ac70fa4c0a5,
	.signature_hash=	_JC_JLONG(0x78894ac70fa4c0a5),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMThrowable$method$fillInStackTrace$78894ac70fa4c0a5,
	.num_parameters=	1,
};

_jc_java_lang_VMThrowable$object * _JC_JCNI_ATTR
_jc_java_lang_VMThrowable$method$fillInStackTrace$78894ac70fa4c0a5(_jc_env *const env, _jc_java_lang_Throwable$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMThrowable$method_info$fillInStackTrace$78894ac70fa4c0a5, &retval, param0);
	return retval.l;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>()
//

static _jc_linenum _jc_java_lang_VMThrowable$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_lang_VMThrowable$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMThrowable$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMThrowable$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMThrowable$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_java_lang_VMThrowable$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMThrowable$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMThrowable, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_lang_VMThrowable$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_lang_VMThrowable$object *this)
{
	struct _jc_java_lang_VMThrowable$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(60);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// final native java.lang.StackTraceElement[] getStackTrace(java.lang.Throwable)
//

static const unsigned char _jc_java_lang_VMThrowable$param_ptypes$getStackTrace$6bf04a7562bb9b69[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMThrowable$param_types$getStackTrace$6bf04a7562bb9b69[] = {
	&_jc_java_lang_Throwable$type
};

_jc_method _jc_java_lang_VMThrowable$method_info$getStackTrace$6bf04a7562bb9b69 = {
	.name=			"getStackTrace",
	.signature=		"(Ljava/lang/Throwable;)[Ljava/lang/StackTraceElement;",
	.class=			&_jc_java_lang_VMThrowable$type,
	.param_types=		&_jc_java_lang_VMThrowable$param_types$getStackTrace$6bf04a7562bb9b69,
	.return_type=		&_jc_java_lang_StackTraceElement$array$type,
	.param_ptypes=		&_jc_java_lang_VMThrowable$param_ptypes$getStackTrace$6bf04a7562bb9b69,
	.signature_hash=	_JC_JLONG(0x6bf04a7562bb9b69),
	.access_flags=		_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMThrowable$method$getStackTrace$6bf04a7562bb9b69,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_VMThrowable$vtable, java_lang_VMThrowable.getStackTrace$6bf04a7562bb9b69) / sizeof(void *),
	.num_parameters=	1,
};

_jc_object_array * _JC_JCNI_ATTR
_jc_java_lang_VMThrowable$method$getStackTrace$6bf04a7562bb9b69(_jc_env *const env, _jc_java_lang_VMThrowable$object *this, _jc_java_lang_Throwable$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMThrowable$method_info$getStackTrace$6bf04a7562bb9b69, &retval, this, param0);
	return retval.l;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_VMThrowable$methods[] = {
	&_jc_java_lang_VMThrowable$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_lang_VMThrowable$method_info$fillInStackTrace$78894ac70fa4c0a5,
	&_jc_java_lang_VMThrowable$method_info$getStackTrace$6bf04a7562bb9b69
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_VMThrowable$instanceof_hash_bucket_65[] = {
	&_jc_java_lang_VMThrowable$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_VMThrowable$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_VMThrowable$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[65]=	_jc_java_lang_VMThrowable$instanceof_hash_bucket_65,
	[101]=	_jc_java_lang_VMThrowable$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_VMThrowable$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/StackTraceElement",	_JC_JLONG(0xa817ca1826b12888) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_VMThrowable$vtype _jc_java_lang_VMThrowable$type = {
    .type= {
	.name=			"java/lang/VMThrowable",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xc8d6a6ffc5c1acc1),
		.source_file=		"VMThrowable.java",
		.instance_size=		sizeof(_jc_java_lang_VMThrowable$refs) + sizeof(_jc_java_lang_VMThrowable$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_lang_VMThrowable$fields) / sizeof(*_jc_java_lang_VMThrowable$fields),
		.fields=		_jc_java_lang_VMThrowable$fields,
		.num_methods=		sizeof(_jc_java_lang_VMThrowable$methods) / sizeof(*_jc_java_lang_VMThrowable$methods),
		.methods=		_jc_java_lang_VMThrowable$methods,
		.instanceof_hash_table=	_jc_java_lang_VMThrowable$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_lang_VMThrowable$class_depends) / sizeof(*_jc_java_lang_VMThrowable$class_depends),
		.class_depends=		_jc_java_lang_VMThrowable$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_VMThrowable= {
	    .getStackTrace$6bf04a7562bb9b69=
		&_jc_java_lang_VMThrowable$method$getStackTrace$6bf04a7562bb9b69,
	},
    }
};
